@@ -6,7 +6,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1995-08-10
- * modified: 2004-02-13
+ * modified: 2004-04-20
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -55,13 +55,37 @@
 @implementation App
 
 /*
- * modified: 24.08.98
+ * modified: 2004-04-20
  * Initializes the defaults.
  */
 + (void)initialize
 {   NSMutableDictionary	*registrationDict = [NSMutableDictionary dictionary];
 
     [registrationDict setObject:@"." forKey:@"NSDecimalSeparator"];
+
+    /* General Preferences defaults */
+#ifdef __APPLE__
+    [registrationDict setObject:@"NO" forKey:@"doCaching"];
+#else
+    [registrationDict setObject:@"YES" forKey:@"doCaching"];
+#endif
+    [registrationDict setObject:@"0" forKey:@"unit"];
+    [registrationDict setObject:@"NO" forKey:@"removeBackups"];
+    [registrationDict setObject:@"NO" forKey:@"expertMode"];
+    [registrationDict setObject:@"0" forKey:@"snap"];
+    [registrationDict setObject:@"." forKey:@"NSDecimalSeparator"];
+
+    /* Import preferences defaults */
+    [registrationDict removeAllObjects];
+    [registrationDict setObject:@"hpgl_8Pen" forKey:@"hpglParmsFileName"];
+    [registrationDict setObject:@"gerber" forKey:@"gerberParmsFileName"];
+    [registrationDict setObject:@"" forKey:@"dinParmsFileName"];
+    [registrationDict setObject:@"25.4" forKey:@"dxfRes"];
+    [registrationDict setObject:@"NO" forKey:@"psFlattenText"];
+    [registrationDict setObject:@"NO" forKey:@"psPreferArcs"];
+    [registrationDict setObject:@"NO" forKey:@"colorToLayer"];
+    [registrationDict setObject:@"NO" forKey:@"fillObjects"];
+
     [[NSUserDefaults standardUserDefaults] registerDefaults:registrationDict];
 }
 
@@ -638,13 +662,6 @@
         default: NSLog(@"App, changeFileType: Unknown file type");
     }
 }
-- (void)setSaveType:(NSString*)ext
-{   NSDictionary	*dict = [NSDictionary dictionaryWithObjectsAndKeys:@"0", DOCUMENT_EXT, @"1", EPS_EXT, @"2", GERBER_EXT, @"3", DXF_EXT, @"4", HPGL_EXT, @"5", FONT_EXT, @"6", DIN_EXT, nil];
-
-    [[self saveAsPanel] setRequiredFileType:ext];
-    [spaFormatPopUp selectItemAtIndex:[dict intForKey:ext]];
-    [[spaFormatPopUp selectedItem] setEnabled:YES];
-}
 
 - (void)revertToSaved:sender
 {   NSString	*fileName = [[self currentDocument] filename];
@@ -671,6 +688,17 @@
     return openpanel;
 }
 
+- (NSSavePanel*)saveAsPanelWithSaveType:(NSString*)ext
+{   NSSavePanel		*savePanel = [NSSavePanel savePanel];
+    NSDictionary	*dict = [NSDictionary dictionaryWithObjectsAndKeys:@"0", DOCUMENT_EXT, @"1", EPS_EXT, @"2", GERBER_EXT, @"3", DXF_EXT, @"4", HPGL_EXT, @"5", FONT_EXT, @"6", DIN_EXT, nil];
+
+    [savePanel setAccessoryView:[savePanelAccessory retain]];
+    [savePanel setRequiredFileType:ext];
+    [spaFormatPopUp selectItemAtIndex:[dict intForKey:ext]];
+    [[spaFormatPopUp selectedItem] setEnabled:YES];
+    return savePanel;
+}
+
 /*
  * Returns a SavePanel with the accessory view which allows the user to
  * pick which type of file she wants to save.
